# SPDX-License-Identifier: MIT

"""
Since this package doesn't do anything beyond providing bindings, all we can
do is trying to ensure that those bindings are functional.
"""


def test_smoke():
    """
    lib and ffi can be imported and looks OK.
    """
    from _argon2_cffi_bindings import ffi, lib

    assert repr(ffi).startswith("<_cffi_backend.FFI object at")
    assert repr(lib).startswith("<Lib object for")

    assert 19 == lib.ARGON2_VERSION_NUMBER
    assert 42 == lib.argon2_encodedlen(1, 2, 3, 4, 5, lib.Argon2_id)



import pytest

from _argon2_cffi_bindings._ffi_build import _get_target_platform


@pytest.mark.parametrize(
    ("arch_flags", "expected"),
    [
        (" -arch arm64", "arm64"),
        ("abc -arch  arm64  xyz", "arm64"),
        ("abc -arch  aRm64  xyz", "arm64"),
        ("nonsense ", "FOO"),
        ("", "FOO"),
    ],
)
def test_arch(arch_flags, expected):
    """
    _get_target_platform parses ARCHFLAGS and returns the default value if
    it doesn't find anything.
    """
    assert expected == _get_target_platform(arch_flags, "FOO")



# SPDX-License-Identifier: MIT

import platform
import sys
import sysconfig

from setuptools import setup


cmdclass = {}

if platform.python_implementation() == "CPython":
    try:
        try:
            from setuptools.command.bdist_wheel import bdist_wheel
        except ImportError:
            from wheel.bdist_wheel import bdist_wheel

        class BDistWheel(bdist_wheel):
            def finalize_options(self):
                # Free-threaded CPython doesn't support limited API.
                if sysconfig.get_config_var("Py_GIL_DISABLED"):
                    self.py_limited_api = False
                else:
                    self.py_limited_api = f"cp3{sys.version_info[1]}"

                super().finalize_options()

        cmdclass["bdist_wheel"] = BDistWheel
    except ImportError:
        pass


if __name__ == "__main__":
    setup(
        # Ensure limited API is set on CPython
        cmdclass=cmdclass,
        # CFFI
        zip_safe=False,
        ext_package="_argon2_cffi_bindings",
        cffi_modules=["src/_argon2_cffi_bindings/_ffi_build.py:ffi"],
    )
